use 5.014;

use strict;
use warnings;

use Test::More;

=name

Data::Object::Func::Integer

=abstract

Functions for Integer Data

=synopsis

  use Data::Object::Func::Integer;

=description

Data::Object::Func::Integer is an abstract base class for function classes in
the Data::Object::Func::Integer space.

=cut

use_ok "Data::Object::Func::Integer";

ok 1 and done_testing;
