use strict;
use warnings;
use Test::More;

use_ok 'Data::Object::Func::Code';
use_ok 'Data::Object::Func::Code::Call';
use_ok 'Data::Object::Func::Code::Compose';
use_ok 'Data::Object::Func::Code::Conjoin';
use_ok 'Data::Object::Func::Code::Curry';
use_ok 'Data::Object::Func::Code::Defined';
use_ok 'Data::Object::Func::Code::Disjoin';
use_ok 'Data::Object::Func::Code::Next';
use_ok 'Data::Object::Func::Code::Rcurry';

ok 1 and done_testing;
