use strict;
use warnings;
use Test::More;

use_ok 'Data::Object::Func::Hash';
use_ok 'Data::Object::Func::Hash::Clear';
use_ok 'Data::Object::Func::Hash::Count';
use_ok 'Data::Object::Func::Hash::Defined';
use_ok 'Data::Object::Func::Hash::Delete';
use_ok 'Data::Object::Func::Hash::Each';
use_ok 'Data::Object::Func::Hash::EachKey';
use_ok 'Data::Object::Func::Hash::EachNValues';
use_ok 'Data::Object::Func::Hash::EachValue';
use_ok 'Data::Object::Func::Hash::Empty';
use_ok 'Data::Object::Func::Hash::Eq';
use_ok 'Data::Object::Func::Hash::Exists';
use_ok 'Data::Object::Func::Hash::FilterExclude';
use_ok 'Data::Object::Func::Hash::FilterInclude';
use_ok 'Data::Object::Func::Hash::Fold';
use_ok 'Data::Object::Func::Hash::Ge';
use_ok 'Data::Object::Func::Hash::Get';
use_ok 'Data::Object::Func::Hash::Grep';
use_ok 'Data::Object::Func::Hash::Gt';
use_ok 'Data::Object::Func::Hash::Head';
use_ok 'Data::Object::Func::Hash::Invert';
use_ok 'Data::Object::Func::Hash::Iterator';
use_ok 'Data::Object::Func::Hash::Join';
use_ok 'Data::Object::Func::Hash::Keys';
use_ok 'Data::Object::Func::Hash::Le';
use_ok 'Data::Object::Func::Hash::Length';
use_ok 'Data::Object::Func::Hash::List';
use_ok 'Data::Object::Func::Hash::Lookup';
use_ok 'Data::Object::Func::Hash::Lt';
use_ok 'Data::Object::Func::Hash::Map';
use_ok 'Data::Object::Func::Hash::Merge';
use_ok 'Data::Object::Func::Hash::Ne';
use_ok 'Data::Object::Func::Hash::Pairs';
use_ok 'Data::Object::Func::Hash::Reset';
use_ok 'Data::Object::Func::Hash::Reverse';
use_ok 'Data::Object::Func::Hash::Set';
use_ok 'Data::Object::Func::Hash::Slice';
use_ok 'Data::Object::Func::Hash::Sort';
use_ok 'Data::Object::Func::Hash::Tail';
use_ok 'Data::Object::Func::Hash::Unfold';
use_ok 'Data::Object::Func::Hash::Values';

ok 1 and done_testing;
